@@ -3,10 +3,10 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.3002';
+our $VERSION = '0.3003';
 
 use Math::Bezier ();
-use MIDI::Util qw(dura_size set_chan_patch set_time_signature);
+use MIDI::Util qw(dura_size reverse_dump set_chan_patch set_time_signature);
 use Music::Duration;
 
 use Moo;
@@ -382,19 +382,29 @@ sub pattern {
 
     $args{instrument} ||= $self->snare;
     $args{patterns}   ||= [];
-    $args{duration}   ||= $self->quarter;
     $args{beats}      ||= $self->beats;
     $args{negate}     ||= 0;
     $args{count}      ||= 0;
     $args{repeat}     ||= 1;
-    $args{vary}       ||= {
-        0 => sub { $self->rest( $args{duration} ) },
-        1 => sub { $self->note( $args{duration}, $args{instrument} ) },
-    };
 
     return unless @{ $args{patterns} };
 
-    my $size = dura_size( $args{duration} );
+    # set size and duration
+    my $size;
+    if ( $args{duration} ) {
+        $size = dura_size( $args{duration} ) || 1;
+    }
+    else {
+        $size = 4 / length( $args{patterns}->[0] );
+        my $dump = reverse_dump('length');
+        $args{duration} = $dump->{$size} || $self->quarter;
+    }
+
+    # set the default beat-string variations
+    $args{vary} ||= {
+        0 => sub { $self->rest( $args{duration} ) },
+        1 => sub { $self->note( $args{duration}, $args{instrument} ) },
+    };
 
     set_chan_patch( $self->score, $self->channel, $args{instrument} );
 
@@ -416,15 +426,12 @@ sub pattern {
 sub sync_patterns {
     my ($self, %patterns) = @_;
 
-    my $duration = delete $patterns{duration} || $self->quarter;
-
     my @subs;
     for my $instrument (keys %patterns) {
         push @subs, sub {
             $self->pattern(
                 instrument => $instrument,
                 patterns   => $patterns{$instrument},
-                duration   => $duration,
             );
         },
     }
@@ -471,7 +478,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.3002
+version 0.3003
 
 =head1 SYNOPSIS
 
@@ -846,15 +853,15 @@ Defaults:
 
 =head2 sync_patterns
 
-  $d->sync_patterns( $instrument1 => $patterns1, $inst2 => $pats2, ..., %options );
+  $d->sync_patterns( $instrument1 => $patterns1, $inst2 => $pats2, ... );
   $d->sync_patterns(
-      duration    => $d->eighth,
       $d->open_hh => [ ('11111111') x $d->bars ],
-      $d->snare   => [ ('00100010') x $d->bars ],
-      $d->kick    => [ ('10001100') x $d->bars ],
+      $d->snare   => [ ('0101') x $d->bars ],
+      $d->kick    => [ ('1010') x $d->bars ],
+      ...
   );
 
-Execute the C<patterns> method for multiple voices.
+Execute the C<pattern> method for multiple voices.
 
 Option defaults:
 
